@@ -1,5 +1,5 @@
 /* blue6.cxx
-     $Id: blue6.cxx,v 1.23 1998/09/07 00:49:30 elf Exp $
+     $Id: blue6.cxx,v 1.24 2001/07/23 01:55:05 elf Exp $
 
    written by Marc Singer
    22 February 1998
@@ -566,7 +566,7 @@ void Window::init (Termcap* pTermcap)
   m_rc.m_dy = m_pTermcap->num (termcapNumLines);
 
   if (!m_pListOp)
-    m_pListOp = new list<Op*>;
+    m_pListOp = new std::list<Op*>;
 
   activate (true);
 }
