@@ -1,5 +1,5 @@
 /* main.cxx
-     $Id: main.cxx,v 1.48 1998/09/11 00:03:44 elf Exp $
+     $Id: main.cxx,v 1.54 2001/10/20 19:31:04 elf Exp $
 
    written by Marc Singer
    12 August 1996
@@ -53,6 +53,7 @@
 #include "version.h"
 
 #include "curves.h"
+#undef umode_t			// *** See NOTES
 #include "signal.h"
 #include "options.h"
 #include "file.h"
@@ -80,8 +81,8 @@ typedef enum {
 char* g_szProgram;
 
 extern int g_maskTrace;
-int do_usage (OPTION*, char*);
-int do_version (OPTION*, char*);
+int do_usage (OPTION*, const char*);
+int do_version (OPTION*, const char*);
 
 OPTION g_rgOption[] = {
   { "debug",	OPTION_F_SET_INT | OPTION_F_ARGUMENT,
@@ -98,7 +99,7 @@ void signal_suspend (LSignalHandle handle, void*)
 {
   if (LSignal::signal_of (handle) == SIGTSTP) {
     LSignal::release (SIGTSTP, signal_suspend, NULL);
-//    fprintf (stderr, "Suspending\n");
+    //    fprintf (stderr, "Suspending\n");
     raise (LSignal::signal_of (handle));
   }
   else
@@ -114,7 +115,7 @@ int read_command (LCurves* pCurves)
   return result;
 }
 
-int do_usage (OPTION*, char*)
+int do_usage (OPTION*, const char*)
 {
   printf (
 "usage: %s [options]\n"
@@ -126,7 +127,7 @@ int do_usage (OPTION*, char*)
   return 1;
 }  /* do_usage */
 
-int do_version (OPTION*, char*)
+int do_version (OPTION*, const char*)
 {
   printf ("CurVeS version %s -- %s\n", g_szVersion, g_szCopyright);
   return 1;
@@ -151,12 +152,17 @@ int main (int argc, char** argv)
   g_preferences.associate ("SenseBinaryFiles", "yes");
   g_preferences.associate ("Sort", "ca");
   //  g_preferences.associate ("CommitCommentEditor", "internal");
-  g_preferences.associate ("ColorScheme", "0");
+  g_preferences.associate ("ColorScheme", "1");
   g_preferences.associate ("InhibitAltCharset", "no");
-  g_preferences.associate ("UseStatusHash", "yes");
+  g_preferences.associate ("UseStatusHash", "no");
   g_preferences.associate ("cvs", "cvs");
   g_preferences.associate ("cvs_server", "");
-  g_preferences.associate ("more", "more");
+  {
+    const char* szPager = getenv ("PAGER");
+    if (szPager == NULL)
+      szPager = "more";
+    g_preferences.associate ("more", szPager);
+  }
   g_preferences.transfer_defaults ();
   g_preferences.read (SZ_PATH_PREFERENCES);
 
