@@ -1,5 +1,5 @@
 /* termcap.cxx
-     $Id: termcap.cxx,v 1.19 1998/10/09 06:17:55 elf Exp $
+     $Id: termcap.cxx,v 1.21 2001/10/20 19:31:04 elf Exp $
 
    written by Marc Singer
    20 December 1996
@@ -513,7 +513,13 @@ int Termcap::_compose_i (int field, char* pb, va_list ap) const
 	state = 0;
 	break;
 
+      case '\'':		// Character constant
+	iConstant = 0;
+	state = 4;
+	break;
+
       default:
+//	printf ("<<%s>>", (const char*) pField->pv);
 	assert_ (0);
 	break;
       }
@@ -541,6 +547,16 @@ int Termcap::_compose_i (int field, char* pb, va_list ap) const
       else
 	assert_ (0);
       break;
+
+    case 4:			// Single character constant
+      assert_ (cStackLim < int (sizeof (rgStack)/sizeof (int)));
+      if (*pbMethod == '\'') {
+	rgStack[cStackLim++] = iConstant;
+	state = 0;
+      }
+      else
+	iConstant = *pbMethod;
+      break;
     }
   }
 
@@ -670,12 +686,12 @@ int Termcap::num (int field)
 
   switch (field) {
   case termcapNumLines:
-    return g_cLines ? g_cLines : int (pField->pv);
+    return g_cLines ? g_cLines : int (VOIDPINT (pField->pv));
   case termcapNumColumns:
-    return g_cColumns ? g_cColumns : int (pField->pv);
+    return g_cColumns ? g_cColumns : int (VOIDPINT (pField->pv));
 
   default:
-    return int (pField->pv);
+    return int (VOIDPINT (pField->pv));
   }
 }
 
@@ -716,7 +732,7 @@ int Termcap::parse_field (void* pv)
 	     pb[0], pb[1]));
 	  break;
 	}      
-	pField->pv = (void*) atoi (pb + 3);
+	pField->pv = (void*) VOIDPINT (atoi (pb + 3));
 	TRACE ((T_TC_INFO, "%s %d", pField->szName, pField->pv));
 	break;
 
@@ -900,7 +916,7 @@ bool Termcap::parse_terminfo (const char* szTerm)
     case termcapClassBoolean:
       if (pField->index >= _tc_c_boolean ())
 	continue;
-      pField->pv = (void*) (_tc_boolean (pField->index) ? 1 : 0);
+      pField->pv = (void*) VOIDPINT (_tc_boolean (pField->index) ? 1 : 0);
       TRACE ((T_TC_INFO, "%s %s", pField->szName,
 	      pField->pv ? "true" : "false"));
       break;
@@ -908,7 +924,7 @@ bool Termcap::parse_terminfo (const char* szTerm)
     case termcapClassNumber:
       if (pField->index >= _tc_c_num ())
 	continue;
-      pField->pv = (void*) (int) _tc_num (pField->index);
+      pField->pv = (void*) (VOIDPINT) _tc_num (pField->index);
       TRACE ((T_TC_INFO, "%s %d", pField->szName, pField->pv));
       break;
 
@@ -920,7 +936,7 @@ bool Termcap::parse_terminfo (const char* szTerm)
 	continue;
       pField->pv = (void*) _tc_string (pField->index);
       TRACE ((T_TC_INFO, "%s '%s'", pField->szName,
-	      pField->pv ? pField->pv : ""));
+	      pField->pv ? pField->pv : (void*) ""));
       break;
 
     case 0:
